@@ -1,11 +1,5 @@
 .CACHE_ROOT <- ".AnnotationHub"
 
-#.DB_SQLITE <- "annotationhub.sqlite3"  ## "ahtest.sqlite3"
-
-.DB_RESOURCE_FIELDS <- paste(sep=".", collapse=", ", "resources",
-    c("ah_id", "title", "dataprovider", "species", "taxonomyid", "genome",
-      "description"))
-
 .onLoad <- function(libname, pkgname, ...) {
     ## options from getOption or Sys.env or default, in that order
     if (is.null(getAnnotationHubOption("MAX_DOWNLOADS"))) {
@@ -21,7 +15,7 @@
         setAnnotationHubOption("URL", opt)
     }
     if (is.null(getAnnotationHubOption("CACHE"))) {
-        path <- switch(.Platform$OS.type, unix = path.expand("~"),
+        path <- switch(.Platform$OS.type, unix = path.expand("~/"),
                        windows= file.path(gsub("\\\\", "/",
                        Sys.getenv("HOME")), "AppData"))
         opt <- getOption("ANNOTATION_HUB_CACHE", file.path(path, .CACHE_ROOT))
